#!/bin/sh

#***************** local settings ****************************************
#
# -- location of tigreleap source
#
TIGRELEAP_SRC="/data/hspc05/st8h304/TIGREleap"
#
. "${TIGRELEAP_SRC}/tigreleap.settings"
#
#*************************************************************************

get_header () {
    cat $1 | fold | grep --max-count=1 --text $2 | sed -e 's/'$2'[[:space:]]*=[[:space:]]*\([-.[:alnum:]]*\)[[:space:]].*/\1/'
}

echoerr() { printf "%s\n" "$*" >&2; }

##########################################################################

f_verbose=0

if [ $# -gt 0 -a "$1" = "-v" ]
then
    f_verbose=1
    shift
fi

if [ $# -lt 2 ]
then
    echo "$0: usage do_ca_index.sh <file_path> <RV>"
    exit 1
fi

path="$1"
rv="$2"

if ! test -f "${path}"
then
    echo "$0: missing file ${path}"
    exit 1
fi

# --- compute wavelengths

c_light=299792.458
ca_h=3968.47
ca_k=3933.66

vhelio=$( get_header "${path}" VHELIO )

if [ "$f_verbose" -ne 0 ]; then
    echo "vhelio   = |${vhelio}|"
fi

### -- add RV and VHELIO

#
# this seems to be the proper sign handling - which seems to
# indicate that the RV sign is opposite to the VHELIO sign ...
#
vhelio=$( echo "scale=10 ; -( $vhelio - $rv )" | bc )

# delta(lambda) = lambda * ( v / c )
# v>0 redshift

cont1=3901.07
cont2=4001.07

cont1=$( echo "scale=10 ; $cont1 + $cont1 * ( $vhelio / $c_light )" | bc )
cont2=$( echo "scale=10 ; $cont2 + $cont2 * ( $vhelio / $c_light )" | bc )

#echo "cont1    = |${cont1}|"
#echo "cont2    = |${cont2}|"

cont1_l=$( echo "scale=10 ; $cont1 - 10.0" | bc -l )
cont1_h=$( echo "scale=10 ; $cont1 + 10.0" | bc -l )
cont2_l=$( echo "scale=10 ; $cont2 - 10.0" | bc -l )
cont2_h=$( echo "scale=10 ; $cont2 + 10.0" | bc -l )


ca_h=$( echo "scale=10 ; $ca_h + $ca_h * ( $vhelio / $c_light )" | bc )
ca_k=$( echo "scale=10 ; $ca_k + $ca_k * ( $vhelio / $c_light )" | bc )

ca_h_l=$( echo "scale=10 ; $ca_h - 0.5" | bc -l )
ca_h_h=$( echo "scale=10 ; $ca_h + 0.5" | bc -l )
ca_k_l=$( echo "scale=10 ; $ca_k - 0.5" | bc -l )
ca_k_h=$( echo "scale=10 ; $ca_k + 0.5" | bc -l )

if [ "$f_verbose" -ne 0 ]; then
    echo "cont1    = |${cont1_l} - ${cont1_h}|"
    echo "ca_k     = |${ca_k_l} - ${ca_k_h}|"
    echo "ca_h     = |${ca_h_l} - ${ca_h_h}|"
    echo "cont2    = |${cont2_l} - ${cont2_h}|"
fi

echoerr "ca_k     = |${ca_k_l} - ${ca_k_h}|  ${path}"

# --- write input files and call splot

workdir="$( dirname ${path} )"
imfile="$( basename ${path} )"

USERID="$(whoami)"
# cat "${TIGRELEAP_SRC}/login.cl" | sed "s,HOME_LOCATION,${HOME_LOCATION},g" | sed "s,USERID,${USERID},g" > login.cl
cat "${TIGRELEAP_SRC}/login.cl" | sed "s,HOME_LOCATION,${workdir},g" | sed "s,USERID,${USERID},g" > login.cl

rm -f "${workdir}/splot.log"
rm -f "${workdir}/ca.cur"
rm -f "${workdir}/ca_copy.fits"

tmpfile=$( tempfile -d . )

echo "${cont1_l} 1 1 e" >> "${workdir}/ca.cur"
echo "${cont1_h} 1 1 e" >> "${workdir}/ca.cur"
echo "${ca_k_l} 1 1 e"  >> "${workdir}/ca.cur"
echo "${ca_k_h} 1 1 e"  >> "${workdir}/ca.cur"
echo "${ca_h_l} 1 1 e"  >> "${workdir}/ca.cur"
echo "${ca_h_h} 1 1 e"  >> "${workdir}/ca.cur"
echo "${cont2_l} 1 1 e" >> "${workdir}/ca.cur"
echo "${cont2_h} 1 1 e" >> "${workdir}/ca.cur"
echo "0 0 1 q" >> "${workdir}/ca.cur"

{
    echo 'noao'
    echo 'onedspec'
    echo 'stty xterm'
    echo 'cd '${workdir}
    echo 'splot ("'${imfile}'", save_file="splot.log", cursor="ca.cur", xmin=3850, xmax=4050, func="spline3", order=2, low_r=2., high_r=4., niter=10, grow=2., > "dev$null", >G "dev$null")'
    echo 'imdel ("ca_copy", verify=no)'
    echo 'logout'
} | ${CL} > "${tmpfile}"

grep ERROR "${tmpfile}" >/dev/null 2>&1
if [ $? -eq 0 ]
then
    echo "$0: IRAF error, see file ${tmpfile}"
    cat "${tmpfile}"
    exit 1
fi
rm -f "${tmpfile}"

# --- parse result

file="${workdir}/splot.log"
count=0
xx=0
yy=0

if [ "$f_verbose" -ne 0 ]; then
    cat "${file}"
fi

while IFS= read -r line; do
    case $line in
	*center*)
	    count=1
	    ;;
	*)
	    if [ $count -ne 0 ]
	    then
		flux=$( echo ${line} | awk '{ print $3; }' )
		if [ $count -eq 1 ]; then
		    yy=$flux
		elif [ $count -eq 2 ]; then
		    xx=$flux
		elif [ $count -eq 3 ]; then
		    xx=$( echo "scale=10 ; $xx + $flux" | bc -l )
		elif [ $count -eq 4 ]; then
		    yy=$( echo "scale=10 ; $yy + $flux" | bc -l )
		else
		    :
		fi
		if [ "$f_verbose" -ne 0 ]; then
		    echo "$count : $flux"
		fi
		count=$(( count + 1 ))
	    fi
	    ;;
    esac
done < "$file"

# --- compute index

# two, rms = 0.000141671346173
# sindex=$( echo "scale=10 ; (2.0 + $xx) / (40.0 + $yy)" | bc -l )

# one, rms = 0.000140904034615
sindex=$( echo "scale=10 ; ($xx) / ($yy)" | bc -l )
if [ "$f_verbose" -ne 0 ]; then
    echo "lines  = $xx"
    echo "cont   = $yy"
    echo "sindex = $sindex"
fi

echo $sindex

exit 0



