#! /bin/sh

#***************** local settings ****************************************
#
# -- location of tigreleap source
#
if test -z "${TIGRELEAP_SRC}"
then
    TIGRELEAP_SRC=$( dirname $0 )
fi
#
. "${TIGRELEAP_SRC}/tigreleap.settings"
#
#*************************************************************************

f_clean=1
f_onlycalib=0
tigre_master_flat=
tigre_master_thar=
f_defthar=0
f_defflat=0

help() {
    echo "$0: usage tigreleap.sh [--no-cleanup][--only-calib] <YYYY_MM_DD> <R|B>"
    echo "   [--no-cleanup] do not delete intermediat results"
    echo "   [--only-calib] do not process science frames"
    echo "   [-F] use default master flat"
    echo "   [-T] use default master thar"
    echo "   [--masterflat <path>] use <path> as master flat"
    echo "   [--masterthar <path>] use <path> as master thar"
    echo
    echo "  Output: .merged.fits (variance weighted, cleaned, orders merged)"
    echo "          .merged_S.fits (no variance weighting, no cleaning)"
    echo "          _orders.ec.fits (variance weighted, cleaned, not merged)"
    echo "          _orders_S.ec.fits (no variance weighting, no cleaning)"
    echo "          _sigma.ec.fits (sigma for _orders.ec.fits)"
    echo
    echo "  Known bugs: may crash if you have an IRAF session open"
    echo
    echo "  local settings defined in script header:"
    echo
    cat $0 | head -n 11 | tail -n 9
}

while [ "$1" != "" ]; do
    case $1 in
    # -p=*|--prefix=*)
    # PREFIX=`echo $i | sed 's/[-a-zA-Z0-9]*=//'`
    # ;;
	--no-cleanup)
	    f_clean=0
	    shift
	    ;;
	--only-calib|--onlycalib)
	    f_onlycalib=1
	    shift
	    ;;
	--masterflat|--master-flat)
	    shift
	    export tigre_master_flat="$1"
	    shift
	    ;;
	-F)
	    f_defflat=1
	    shift
	    ;;
	--masterthar|--master-thar)
	    shift
	    export tigre_master_thar="$1"
	    shift
	    ;;
	-T)
	    f_defthar=1
	    shift
	    ;;
	-h|--help)
	    help
	    exit 0
	    ;;
	*)
	    break
	    ;;
    esac
done

if [ $# -lt 2 ]
then
    help
    exit 1
fi

TIGRE_DATE="$(echo $1 | sed s,-,_,g)"
TIGRE_BAND="$2"

# -- date check --
#
# Channel R: 2014_12_01 to 2015_05_14 observation with different CCD
# Channel R: 2015_05_14 last observation night with old setting
# Channel R: 2015_05_23 repaired camera installed, wavelength setting changed
#
obsdate=$( echo ${TIGRE_DATE} | sed 's,_,,g' )
if [ ${obsdate} -lt 20150523 ]
then
    if [ x"${TIGRE_BAND}" = xR ]
    then
	echo "$0: channel R unsupported for dates before 2015_05_23" 1>&2;
	exit 1;
    fi
fi

if [ ${f_defthar} -ne 0 ]
then
    if [ x"${TIGRE_BAND}" = xR ]
    then
	export tigre_master_thar="${TIGRELEAP_SRC}/${DEFAULT_MASTER_THAR_R}"
    else
	export tigre_master_thar="${TIGRELEAP_SRC}/${DEFAULT_MASTER_THAR_B}"
    fi
fi
if [ ${f_defflat} -ne 0 ]
then
    if [ x"${TIGRE_BAND}" = xR ]
    then
	export tigre_master_flat="${TIGRELEAP_SRC}/${DEFAULT_MASTER_FLAT_R}"
    else
	export tigre_master_flat="${TIGRELEAP_SRC}/${DEFAULT_MASTER_FLAT_B}"
    fi
fi


PWD_DIR="$(pwd)"
DATE="$(date --iso-8601=seconds)"

export rawdir="${TIGRE_RAW_ARCHIVE}/${TIGRE_DATE}/${TIGRE_BAND}/"
export workdir="${PWD_DIR}/${TIGRE_DATE}/${TIGRE_BAND}/"
export tigreleap="${TIGRE_IRAF_SOURCE}/"


if [ ! -d "${rawdir}" ]
then
    echo "$0: raw data directory ${rawdir} not found" 1>&2;
    exit 1
fi

if [ ! -d "${workdir}" ]
then
    mkdir -p "${workdir}"
    if [ $? -ne 0 ] 
    then
	echo "$0: error creating working directory ${workdir}" 1>&2;
	exit 1
    fi
fi

cd "${workdir}"
if [ $? -ne 0 ] 
then
    echo "$0: error cd into working directory ${workdir}" 1>&2;
    exit 1
fi

mkdir -p ./iraf/uparm

# -- Prepare IRAF environment (copy login.cl)
#
USERID="$(whoami)"
# cat "${TIGRELEAP_SRC}/login.cl" | sed "s,HOME_LOCATION,${HOME_LOCATION},g" | sed "s,USERID,${USERID},g" > login.cl
cat "${TIGRELEAP_SRC}/login.cl" | sed "s,HOME_LOCATION,${workdir},g" | sed "s,USERID,${USERID},g" > login.cl

# -- Run IRAF commands, output goes to logfile
#
{
    echo 'stty vt100'
    echo 'cd '${workdir}
    echo 'set clobber = yes'
    echo 'cl < '${TIGRELEAP_SRC}'/01_prepcalib.cl'
    echo 'cl < '${TIGRELEAP_SRC}'/02_extractcalib.cl'    
    if [ ${f_onlycalib} -eq 0 ]; then
	echo 'cl < '${TIGRELEAP_SRC}'/03_extractspec.cl'
    fi
    echo 'logout'
} | ${CL} 1>"log_${TIGRE_DATE}_${TIGRE_BAND}_${DATE}" 2>&1

# -- clean up
#
if [ ${f_clean} -ne 0 ]
then
    rm -f "${workdir}"/Sci_*_[ab].fits
    rm -f "${workdir}"/Sci_*_[bcdt].ec.fits
    rm -f "${workdir}"/Sci_*_[bcdt]s.ec.fits
    #
    rm -f "${workdir}"/Sci_*_tm.ec.fits
    rm -f "${workdir}"/Sci_*.sc.fits
    rm -f "${workdir}"/Sci_*_tms.ec.fits
    rm -f "${workdir}"/Sci_*.scs.fits
    rm -f "${workdir}"/Sci_*_flat.ec.fits
    #
    rm -f "${workdir}"/ical.*.fits
    rm -f "${workdir}"/login.cl
    rm -f "${workdir}"/lst.*
    rm -f "${workdir}"/subsets
    rm -f "${workdir}"/tigre.dat
    rm -f "${workdir}"/tigre.r.fits
    rm -f "${workdir}"/tigre.r.thar.ec.fits
    rm -f "${workdir}"/flat.sc.fits
    rm -rf "${workdir}"/database/
fi
